"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const schematics_1 = require("@angular-devkit/schematics");
const tasks_1 = require("@angular-devkit/schematics/tasks");
const utils_1 = require("../utils");
exports.default = (options) => {
    return schematics_1.chain([
        addDependencies(options),
        addCommitlintConfigFile(options),
        addDependency(options.husky) ? addHuskyConfig : schematics_1.noop(),
        addDependency(options.commitizen) ? addCommitizenConfig : schematics_1.noop(),
        addDependency(options.standardVersion) ? addNpmRunScript : schematics_1.noop(),
        addDependency(options.standardVersion) && options.issuePrefix
            ? standardVersionConfig(options.issuePrefix)
            : schematics_1.noop(),
        options.skipInstall ? schematics_1.noop() : installDependencies,
    ]);
};
const addDependency = (configForDependency) => {
    return configForDependency === true || typeof configForDependency === 'undefined';
};
const addDependencies = (options) => (tree, context) => {
    context.logger.info('Added npm packages as dev dependencies');
    const packageJson = utils_1.getPackageJson(tree);
    let devDepsToAdd = {
        '@commitlint/cli': '^8.2.0',
        '@commitlint/config-conventional': '^8.2.0',
    };
    if (addDependency(options.commitizen)) {
        devDepsToAdd = Object.assign({}, devDepsToAdd, { commitizen: '^4.0.3', 'cz-conventional-changelog': '^3.0.2' });
    }
    else {
        context.logger.info('- Skips adding commitizen');
    }
    if (addDependency(options.husky)) {
        devDepsToAdd = Object.assign({}, devDepsToAdd, { husky: '^3.0.9' });
    }
    else {
        context.logger.info('- Skips adding husky');
    }
    if (addDependency(options.standardVersion)) {
        devDepsToAdd = Object.assign({}, devDepsToAdd, { 'standard-version': '^7.0.0' });
    }
    else {
        context.logger.info('- Skips adding standard-version');
    }
    packageJson.devDependencies = Object.assign({}, packageJson.devDependencies, devDepsToAdd);
    utils_1.overwritePackageJson(tree, packageJson);
};
const addNpmRunScript = () => (tree, context) => {
    context.logger.info('Added npm script for release');
    const packageJson = utils_1.getPackageJson(tree);
    const scriptsToAdd = {
        release: 'standard-version',
    };
    packageJson.scripts = Object.assign({}, scriptsToAdd, packageJson.scripts);
    utils_1.overwritePackageJson(tree, packageJson);
};
const addHuskyConfig = () => (tree, context) => {
    context.logger.info('Added husky configuration');
    const packageJson = utils_1.getPackageJson(tree);
    const huskyConfig = {
        hooks: {
            'commit-msg': 'commitlint -E HUSKY_GIT_PARAMS',
        },
    };
    packageJson.husky = Object.assign({}, huskyConfig, packageJson.husky);
    utils_1.overwritePackageJson(tree, packageJson);
};
const addCommitizenConfig = () => (tree, context) => {
    context.logger.info('Added commitizen configuration');
    const packageJson = utils_1.getPackageJson(tree);
    const commitizenConfig = {
        commitizen: {
            path: './node_modules/cz-conventional-changelog',
        },
    };
    packageJson.config = Object.assign({}, commitizenConfig, packageJson.config);
    utils_1.overwritePackageJson(tree, packageJson);
};
const standardVersionConfig = (issuePrefix) => (tree, context) => {
    context.logger.info('Added standard-version config');
    const packageJson = utils_1.getPackageJson(tree);
    const scriptsToAdd = {
        issuePrefixes: [issuePrefix],
    };
    packageJson['standard-version'] = Object.assign({}, scriptsToAdd, packageJson['standard-version']);
    utils_1.overwritePackageJson(tree, packageJson);
};
const addCommitlintConfigFile = (options) => (tree, context) => {
    context.logger.info('Added commitlint configuration file');
    const sourceTemplates = schematics_1.url('./files');
    const sourceParameterizedTemplates = schematics_1.apply(sourceTemplates, [
        schematics_1.template({
            issuePrefix: options.issuePrefix || '',
        }),
    ]);
    return schematics_1.mergeWith(sourceParameterizedTemplates)(tree, context);
};
const installDependencies = () => (_tree, context) => {
    context.logger.info('Installs npm dependencies');
    context.addTask(new tasks_1.NodePackageInstallTask());
};
//# sourceMappingURL=index.js.map